@@ -6,7 +6,7 @@ from lintaosp.aosp.aosp import Aosp, AospException
 from lintaosp.cmd.argument import Argument
 from lintaosp.cmd.banner import BANNER
 from lintaosp.config.config import Config, ConfigException
-from lintaosp.flow.flow import Flow, FlowException
+from lintaosp.lint.lint import Lint, LintException
 from lintaosp.logger.logger import Logger
 from lintaosp.queue.queue import Queue, QueueException
 
@@ -37,9 +37,9 @@ def main():
 
     if len(config.listen_url) != 0:
         try:
-            flow = Flow(config)
-            flow.run(aosp.routine)
-        except FlowException as e:
+            lint = Lint(config)
+            lint.run(aosp.routine)
+        except LintException as e:
             Logger.error(str(e))
             return -3
     else:
